==> financial-settlement-domain-0.1.273-sources.jar: com/xforceplus/ultraman/app/financialsettlement/entity/YkbChargeCode.java <==
package com.xforceplus.ultraman.app.financialsettlement.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2022-09-29
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class YkbChargeCode implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * 项目编码
   */
  private String code;

  /**
   * 项目类别编码
   */
  private String type;

  /**
   * 项目名称
   */
  private String name;

  /**
   * 上级项目编码
   */
  @TableField("parentCode")
  private String parentCode;

  /**
   * 项目所有人
   */
  private String owner;

  /**
   * 项目状态
   */
  private String status;

  /**
   * 项目所属区域
   */
  private String area;

  /**
   * 项目所有人Leader
   */
  private String leader;

  /**
   * 项目负责人
   */
  private String manager;

  /**
   * 项目参与人
   */
  private String members;

  /**
   * 组织架构
   */
  private String organization;

  /**
   * KAM
   */
  private String kam;

  /**
   * PMS项目创建时间
   */
  @TableField("pmsCreateTime")
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime pmsCreateTime;

  /**
   * PMS项目更新时间
   */
  @TableField("pmsUpdateTime")
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime pmsUpdateTime;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 同步状态
   */
  @TableField("synStatus")
  private Boolean synStatus;

  /**
   * 同步消息
   */
  @TableField("synMsg")
  private String synMsg;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("code", code);
      map.put("type", type);
      map.put("name", name);
      map.put("parentCode", parentCode);
      map.put("owner", owner);
      map.put("status", status);
      map.put("area", area);
      map.put("leader", leader);
      map.put("manager", manager);
      map.put("members", members);
      map.put("organization", organization);
      map.put("kam", kam);
      map.put("pmsCreateTime", BocpGenUtils.toTimestamp(pmsCreateTime));
      map.put("pmsUpdateTime", BocpGenUtils.toTimestamp(pmsUpdateTime));
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("synStatus", synStatus);
      map.put("synMsg", synMsg);
      return map;
  }

  public static YkbChargeCode fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    YkbChargeCode entity = new YkbChargeCode();
    if(map.containsKey("code")) {
      Object obj = map.get("code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("type")) {
      Object obj = map.get("type");
      if(obj != null) {
        if(obj instanceof String){
          entity.setType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("name")) {
      Object obj = map.get("name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("parentCode")) {
      Object obj = map.get("parentCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setParentCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("owner")) {
      Object obj = map.get("owner");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOwner((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("status")) {
      Object obj = map.get("status");
      if(obj != null) {
        if(obj instanceof String){
          entity.setStatus((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("area")) {
      Object obj = map.get("area");
      if(obj != null) {
        if(obj instanceof String){
          entity.setArea((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("leader")) {
      Object obj = map.get("leader");
      if(obj != null) {
        if(obj instanceof String){
          entity.setLeader((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("manager")) {
      Object obj = map.get("manager");
      if(obj != null) {
        if(obj instanceof String){
          entity.setManager((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("members")) {
      Object obj = map.get("members");
      if(obj != null) {
        if(obj instanceof String){
          entity.setMembers((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("organization")) {
      Object obj = map.get("organization");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOrganization((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("kam")) {
      Object obj = map.get("kam");
      if(obj != null) {
        if(obj instanceof String){
          entity.setKam((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pmsCreateTime")) {
      Object obj = map.get("pmsCreateTime");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setPmsCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setPmsCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setPmsCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setPmsCreateTime(null);
      }
    }
    if(map.containsKey("pmsUpdateTime")) {
      Object obj = map.get("pmsUpdateTime");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setPmsUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setPmsUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setPmsUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setPmsUpdateTime(null);
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("synStatus")) {
      Object obj = map.get("synStatus");
      if(obj != null) {
        if(obj instanceof Boolean) {
          entity.setSynStatus((Boolean)obj);
        } else if(obj instanceof String) {
          entity.setSynStatus(Boolean.valueOf((String)obj));
        }
      } else{
      }
    }
    if(map.containsKey("synMsg")) {
      Object obj = map.get("synMsg");
      if(obj != null) {
        if(obj instanceof String){
          entity.setSynMsg((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}

==> financial-settlement-domain-0.1.333-sources.jar: com/xforceplus/ultraman/app/financialsettlement/entity/YkbChargeCode.java <==
package com.xforceplus.ultraman.app.financialsettlement.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2023-03-30
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class YkbChargeCode implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * 项目编码
   */
  private String code;

  /**
   * 项目类别编码
   */
  private String type;

  /**
   * 项目名称
   */
  private String name;

  /**
   * 上级项目编码
   */
  @TableField("parentCode")
  private String parentCode;

  /**
   * 项目所有人
   */
  private String owner;

  /**
   * 项目状态
   */
  private String status;

  /**
   * 项目所属区域
   */
  private String area;

  /**
   * 项目所有人Leader
   */
  private String leader;

  /**
   * 项目负责人
   */
  private String manager;

  /**
   * 项目参与人
   */
  private String members;

  /**
   * 组织架构
   */
  private String organization;

  /**
   * KAM
   */
  private String kam;

  /**
   * PMS项目创建时间
   */
  @TableField("pmsCreateTime")
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime pmsCreateTime;

  /**
   * PMS项目更新时间
   */
  @TableField("pmsUpdateTime")
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime pmsUpdateTime;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 同步状态
   */
  @TableField("synStatus")
  private Boolean synStatus;

  /**
   * 同步消息
   */
  @TableField("synMsg")
  private String synMsg;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("code", code);
      map.put("type", type);
      map.put("name", name);
      map.put("parentCode", parentCode);
      map.put("owner", owner);
      map.put("status", status);
      map.put("area", area);
      map.put("leader", leader);
      map.put("manager", manager);
      map.put("members", members);
      map.put("organization", organization);
      map.put("kam", kam);
      map.put("pmsCreateTime", BocpGenUtils.toTimestamp(pmsCreateTime));
      map.put("pmsUpdateTime", BocpGenUtils.toTimestamp(pmsUpdateTime));
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("synStatus", synStatus);
      map.put("synMsg", synMsg);
      return map;
  }

  public static YkbChargeCode fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    YkbChargeCode entity = new YkbChargeCode();
    if(map.containsKey("code")) {
      Object obj = map.get("code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("type")) {
      Object obj = map.get("type");
      if(obj != null) {
        if(obj instanceof String){
          entity.setType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("name")) {
      Object obj = map.get("name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("parentCode")) {
      Object obj = map.get("parentCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setParentCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("owner")) {
      Object obj = map.get("owner");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOwner((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("status")) {
      Object obj = map.get("status");
      if(obj != null) {
        if(obj instanceof String){
          entity.setStatus((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("area")) {
      Object obj = map.get("area");
      if(obj != null) {
        if(obj instanceof String){
          entity.setArea((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("leader")) {
      Object obj = map.get("leader");
      if(obj != null) {
        if(obj instanceof String){
          entity.setLeader((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("manager")) {
      Object obj = map.get("manager");
      if(obj != null) {
        if(obj instanceof String){
          entity.setManager((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("members")) {
      Object obj = map.get("members");
      if(obj != null) {
        if(obj instanceof String){
          entity.setMembers((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("organization")) {
      Object obj = map.get("organization");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOrganization((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("kam")) {
      Object obj = map.get("kam");
      if(obj != null) {
        if(obj instanceof String){
          entity.setKam((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pmsCreateTime")) {
      Object obj = map.get("pmsCreateTime");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setPmsCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          entity.setPmsCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setPmsCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setPmsCreateTime(null);
      }
    }
    if(map.containsKey("pmsUpdateTime")) {
      Object obj = map.get("pmsUpdateTime");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setPmsUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          entity.setPmsUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setPmsUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setPmsUpdateTime(null);
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("synStatus")) {
      Object obj = map.get("synStatus");
      if(obj != null) {
        if(obj instanceof Boolean) {
          entity.setSynStatus((Boolean)obj);
        } else if(obj instanceof String) {
          entity.setSynStatus(Boolean.valueOf((String)obj));
        }
      } else{
      }
    }
    if(map.containsKey("synMsg")) {
      Object obj = map.get("synMsg");
      if(obj != null) {
        if(obj instanceof String){
          entity.setSynMsg((String)obj);
        }
      } else{
      }
    }
    return entity;
  }


  protected void setByOQSMap(Map map) {
    if(map.containsKey("code")) {
      Object obj = map.get("code");
      if(obj != null) {
        if(obj instanceof String) {
          this.setCode((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("type")) {
      Object obj = map.get("type");
      if(obj != null) {
        if(obj instanceof String) {
          this.setType((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("name")) {
      Object obj = map.get("name");
      if(obj != null) {
        if(obj instanceof String) {
          this.setName((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("parentCode")) {
      Object obj = map.get("parentCode");
      if(obj != null) {
        if(obj instanceof String) {
          this.setParentCode((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("owner")) {
      Object obj = map.get("owner");
      if(obj != null) {
        if(obj instanceof String) {
          this.setOwner((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("status")) {
      Object obj = map.get("status");
      if(obj != null) {
        if(obj instanceof String) {
          this.setStatus((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("area")) {
      Object obj = map.get("area");
      if(obj != null) {
        if(obj instanceof String) {
          this.setArea((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("leader")) {
      Object obj = map.get("leader");
      if(obj != null) {
        if(obj instanceof String) {
          this.setLeader((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("manager")) {
      Object obj = map.get("manager");
      if(obj != null) {
        if(obj instanceof String) {
          this.setManager((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("members")) {
      Object obj = map.get("members");
      if(obj != null) {
        if(obj instanceof String) {
          this.setMembers((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("organization")) {
      Object obj = map.get("organization");
      if(obj != null) {
        if(obj instanceof String) {
          this.setOrganization((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("kam")) {
      Object obj = map.get("kam");
      if(obj != null) {
        if(obj instanceof String) {
          this.setKam((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("pmsCreateTime")) {
      Object obj = map.get("pmsCreateTime");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setPmsCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          this.setPmsCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          this.setPmsCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else {
        this.setPmsCreateTime(null);
      }
    }
    if(map.containsKey("pmsUpdateTime")) {
      Object obj = map.get("pmsUpdateTime");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setPmsUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          this.setPmsUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          this.setPmsUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else {
        this.setPmsUpdateTime(null);
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setId((Long)obj);
        } else if(obj instanceof String) {
          this.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          this.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setTenantId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String) {
          this.setTenantCode((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          this.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          this.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else {
        this.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          this.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          this.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else {
        this.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          this.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          this.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String) {
          this.setCreateUserName((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String) {
          this.setUpdateUserName((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String) {
          this.setDeleteFlag((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("synStatus")) {
      Object obj = map.get("synStatus");
      if(obj != null) {
        if(obj instanceof Boolean) {
          this.setSynStatus((Boolean)obj);
        } else if(obj instanceof String) {
          this.setSynStatus(Boolean.valueOf((String)obj));
        }
      } else {
      }
    }
    if(map.containsKey("synMsg")) {
      Object obj = map.get("synMsg");
      if(obj != null) {
        if(obj instanceof String) {
          this.setSynMsg((String)obj);
        }
      } else {
      }
    }
  }
}
